@@ -413,6 +413,7 @@ void KcmGtk::save()
 	TQFile file(TQDir::homeDirPath() + "/" + GTK_RC_FILE);
 	file.open(IO_WriteOnly);
 	TQTextStream stream(&file);
+	stream.setEncoding(TQTextStream::Locale);
 
 	TQFont selectedFont(widget->fontKde->isChecked() ? TQApplication::font() : font);
 	TQString fontName = selectedFont.family() + " " +
@@ -509,13 +510,13 @@ void KcmGtk::save()
 	if (file.exists())
 	{
 		file.open(IO_ReadOnly);
-		TQByteArray fileData = file.readAll();
+		stream.setDevice(TQT_TQIODEVICE(&file));
+		TQString fileDataString = stream.read();
 		file.close();
-		
+
 		TQString rcLine = "export GTK2_RC_FILES=$HOME/.gtkrc-2.0";
-		TQString fileDataString(fileData);
 		fileDataString.replace("\n" + rcLine, "\n# (This is no longer needed from version 0.8 of the theme engine)\n# " + rcLine);
-		
+
 		file.open(IO_WriteOnly);
 		stream.setDevice(TQT_TQIODEVICE(&file));
 		stream << fileDataString;
